;****************************************************************************
;*  Copyright (C) 2000-2004  Dallas Semiconductor Corporation. 
;*
;*  All rights Reserved. Printed in U.S.A.
;*  This software is protected by copyright laws of
;*  the United States and of foreign countries.
;*  This material may also be protected by patent laws of the United States 
;*  and of foreign countries.
;*  This software is furnished under a license agreement and/or a
;*  nondisclosure agreement and may only be used or copied in accordance
;*  with the terms of those agreements.
;*  The mere transfer of this software does not imply any licenses
;*  of trade secrets, proprietary technology, copyrights, patents,
;*  trademarks, maskwork rights, or any other form of intellectual
;*  property whatsoever. Dallas Semiconductor retains all ownership rights.
;*
;*     Module Name: SPIMacros
;*
;*     Description: Macros for setting and clearing the port 5 pins used
;*                  for the bit-bang SPI port.
;*
;*        Filename: spimacros.inc
;*
;* Dependant Files: none
;*
;*          Author: JDK
;*
;*        Compiler: Keil uvison
;*
;*         Version: 1 
;*
;*         Created: 12/11/01
;*
;*   Modifications: 02/09/04 - JDK - Added optional ssSynch and removed bit inversion.
;*                  10/14/03 - JDK - Added check for USE_SS to the SET_SS and
;*                                   the CLEAR_SS macros
;*
;****************************************************************************

; Pin Masks

SS_MASK         equ 08H
NOT_SS_MASK     equ NOT(SS_MASK)
MISO_MASK       equ 04H
NOT_MISO_MASK   equ NOT(MISO_MASK)
MOSI_MASK       equ 02H
NOT_MOSI_MASK   equ NOT(MOSI_MASK)
CLK_MASK        equ 01H
NOT_CLK_MASK    equ NOT(CLK_MASK)


; Bit defines.

SKEW	  equ acc.3
CKPOL	  equ acc.0
CKPHA	  equ acc.1
WORDMODE  equ acc.2
USE_SS	  equ acc.4
SYNCH_SS  equ acc.5
INVERT_SS equ acc.6

;-------------------------------------------------------------------

SPI_DELAY  MACRO
	   LOCAL SPI_BURN_MICROS
	   mov   a, r4                  ; a -> delay in microseconds.
SPI_BURN_MICROS:
        REPT  11
        nop
        ENDM
	   djnz  acc, SPI_BURN_MICROS   ;11 + 5 = 16 machine cycles
	   ENDM

;-------------------------------------------------------------------

SET_SS MACRO
       LOCAL SPI_SET_SS_DONT, SPI_SET_SS_INVERT, SPI_SET_SS_BURN
       mov   a,  r5
	   jnb   USE_SS, SPI_SET_SS_DONT
	   jnb   SYNCH_SS, SPI_SET_SS_DONT   
	   jb    INVERT_SS, SPI_SET_SS_INVERT
       orl   p2, #SS_MASK
       sjmp  SPI_SET_SS_DONT
SPI_SET_SS_INVERT:
       anl   p2, #NOT_SS_MASK
SPI_SET_SS_DONT:
       mov   a, #8		; Make up time here to allow
SPI_SET_SS_BURN:	  	; SS to hold for one SPI_CLK time
	   djnz  acc, SPI_SET_SS_BURN
       ENDM

;-------------------------------------------------------------------

CLEAR_SS   MACRO		
       LOCAL SPI_CLEAR_SS_DONT, SPI_CLEAR_SS_INVERT, SPI_CLEAR_SS_BURN
       mov   a,  r5
	   jnb   USE_SS, SPI_CLEAR_SS_DONT
	   jnb   SYNCH_SS, SPI_CLEAR_SS_DONT
	   jb    INVERT_SS, SPI_CLEAR_SS_INVERT
       anl   p2, #NOT_SS_MASK
       sjmp  SPI_CLEAR_SS_DONT
SPI_CLEAR_SS_INVERT:
       orl   p2, #SS_MASK           
SPI_CLEAR_SS_DONT:
       ENDM

;-------------------------------------------------------------------

GET_DATA   MACRO		; Return the bit masked in a
	   LOCAL GET_DATA_DONE
       mov   a, p2
       anl   a, #MISO_MASK
	   jz    GET_DATA_DONE
	   orl   R1_B1, #1      ; Set low bit of destination
GET_DATA_DONE:
	   ENDM

;-------------------------------------------------------------------

SET_DATA   MACRO 		; Put bit 7 of acc onto mosi pin
	   LOCAL SPI_MOSI_HIGH, SPI_SET_DATA_DONE
	   mov   a, R0_B1	; Get source byte
	   jb    acc.7, SPI_MOSI_HIGH
	   anl   p2, #NOT_MOSI_MASK
	   sjmp  SPI_SET_DATA_DONE
SPI_MOSI_HIGH:
	   orl   p2, #MOSI_MASK
SPI_SET_DATA_DONE:
       ENDM		
	   
;-------------------------------------------------------------------

SET_CLK    MACRO
       orl   p2, #CLK_MASK
       ENDM

;-------------------------------------------------------------------

CLEAR_CLK  MACRO
       anl   p2, #NOT_CLK_MASK
       ENDM

;-------------------------------------------------------------------

GETX  MACRO
           movx  a, @dptr
           ENDM

;-------------------------------------------------------------------

PUTX  MACRO
           movx  @dptr, a
           ENDM

;-------------------------------------------------------------------

R0_B0     equ 0                         ; Register bank 0 equates.
R1_B0     equ 1
R2_B0     equ 2
R3_B0     equ 3
R4_B0     equ 4
R5_B0     equ 5
R6_B0     equ 6
R7_B0     equ 7
;
R0_B1     equ 8                         ; Register bank 1 equates.
R1_B1     equ 9
R2_B1     equ 0AH
R3_B1     equ 0BH
R4_B1     equ 0CH
R5_B1     equ 0DH
R6_B1     equ 0EH
R7_B1     equ 0FH
;
R0_B2     equ 10H                       ; Register bank 2 equates.
R1_B2     equ 11H
R2_B2     equ 12H
R3_B2     equ 13H
R4_B2     equ 14H
R5_B2     equ 15H
R6_B2     equ 16H
R7_B2     equ 17H
;
R0_B3     equ 18H                       ; Register bank 3 equates.
R1_B3     equ 19H
R2_B3     equ 1AH
R3_B3     equ 1BH
R4_B3     equ 1CH
R5_B3     equ 1DH
R6_B3     equ 1EH
R7_B3     equ 1FH

